export const parseSelector = (slotName, ngSelectors) => {
    if ((slotName.startsWith('[') && slotName.endsWith(']')) ||
        ngSelectors.some((s) => s === `[${slotName}]`)) {
        return {
            type: 'directive',
            slotName,
        };
    }
    if (ngSelectors.some((s) => s === slotName)) {
        return {
            type: 'element',
            slotName,
        };
    }
    return {
        type: undefined,
        slotName,
    };
};
export const applySlotContent = ({ slotName, content, ngSelectors, ngTemplateOutlets, }) => {
    // if the slotname is default we return the content as is
    if (slotName === 'default') {
        return content;
    }
    // If a user manually adds a ng-template outlet, we don't apply the slot
    if (content.startsWith('<ng-template')) {
        return content;
    }
    // If the slotname is a ng-template outlet, we wrap the content in a ng-template outlet
    if (ngTemplateOutlets === null || ngTemplateOutlets === void 0 ? void 0 : ngTemplateOutlets.includes(slotName)) {
        return `<ng-template \n#${slotName}>\n${content}\n</ng-template>`;
    }
    const selectorInfo = parseSelector(slotName, ngSelectors);
    if (selectorInfo.type === 'directive') {
        // Add the directive after the component name
        const firstSpaceIndex = content.indexOf(' ');
        if (firstSpaceIndex === -1) {
            // If there's no space, add the directive at the end of the opening tag
            return content.replace('>', ` ${selectorInfo.slotName}>`);
        }
        // Insert the directive after the component name
        return `${content.slice(0, firstSpaceIndex)} ${selectorInfo.slotName}${content.slice(firstSpaceIndex)}`;
    }
    if (selectorInfo.type === 'element') {
        // If the content already starts with the element specified in the slotName, return as is
        // This is to avoid double wrapping the content in an element
        if (content.trim().startsWith(`<${selectorInfo.slotName}`)) {
            return content;
        }
        // If the slotname is an element we wrap the content in an element with the slotname
        return `<${selectorInfo.slotName}>\n${content}\n</${selectorInfo.slotName}>`;
    }
    // if nothing matches, we return the content as is
    return content;
};
//# sourceMappingURL=apply-slot-content.mjs.map