import { parseTemplate, TmplAstTemplate, } from '@angular/compiler';
/**
 * Extracts the ng-template outlets from the component decorator data.
 * Returns an array of ng-template outlets reference names.
 */
export function extractNgTemplateOutlets(decoratorData) {
    const { template, templateUrl, preserveWhitespaces } = decoratorData;
    if (template && templateUrl) {
        const options = {
            preserveWhitespaces: preserveWhitespaces !== null && preserveWhitespaces !== void 0 ? preserveWhitespaces : false,
        };
        const { nodes } = parseTemplate(template, templateUrl, options);
        return nodes.flatMap((node) => {
            var _a;
            // using `.flatMap` b/c `.filter().map()` does not type narrow until TypeScript 5.6 drops
            if (!(node instanceof TmplAstTemplate))
                return [];
            if (node.tagName !== 'ng-template')
                return [];
            const name = (_a = node.references[0]) === null || _a === void 0 ? void 0 : _a.name;
            if (!name)
                return [];
            return [name];
        });
    }
    return [];
}
//# sourceMappingURL=extract-ng-template-outlets.mjs.map