import { getComponentDecoratorData, reflectionCapabilities, reflectComponentType, } from './ng-utils.mjs';
import { isComponent, isInput, isOutput } from './ng-type-guards.mjs';
import { extractNgTemplateOutlets } from './extract-ng-template-outlets.mjs';
export function analyzeComponent(component) {
    if (!isComponent(component)) {
        throw new Error(`Component is not a valid component ${component === null || component === void 0 ? void 0 : component.name}`);
    }
    const decoratorData = getComponentDecoratorData(component);
    const { isStandalone, ngContentSelectors, selector } = reflectComponentType(component);
    // Sometimes the selector is a comma-separated list of multiple selectors
    // so we normalize selectors by taking only the first one
    const normalizedSelectors = ngContentSelectors === null || ngContentSelectors === void 0 ? void 0 : ngContentSelectors.map((s) => s.split(',')[0].trim());
    const propMetadata = reflectionCapabilities.propMetadata(component);
    const ngTemplateOutlets = extractNgTemplateOutlets(decoratorData);
    const { inputs, outputs } = Object.entries(propMetadata || {}).reduce((acc, [propName, decorators = []]) => {
        decorators.forEach((dec) => {
            if (isInput(dec)) {
                acc.inputs.push({
                    propName,
                    required: typeof dec === 'string' ? false : !!dec.required,
                    templateName: typeof dec === 'string' ? dec : dec.alias || propName,
                });
            }
            else if (isOutput(dec)) {
                acc.outputs.push({
                    propName,
                    templateName: dec.alias || propName,
                });
            }
        });
        return acc;
    }, {
        inputs: [],
        outputs: [],
    });
    return {
        inputs,
        outputs,
        decoratorData,
        isStandalone,
        ngContentSelectors: normalizedSelectors,
        ngTemplateOutlets,
        selector,
    };
}
//# sourceMappingURL=ng-component-analyzer.mjs.map