import { NgModule } from '@angular/core';
import { reflectionCapabilities } from './ng-utils.mjs';
const extractNgModuleMetadata = async (importItem) => {
    const target = importItem && importItem.ngModule ? importItem.ngModule : importItem;
    const decorators = reflectionCapabilities.annotations(target);
    if (!decorators || decorators.length === 0) {
        return null;
    }
    const ngModuleDecorator = decorators.find((decorator) => decorator instanceof NgModule);
    if (!ngModuleDecorator) {
        return null;
    }
    return ngModuleDecorator;
};
/**
 * Avoid component redeclaration
 *
 * Checks recursively if the component has already been declared in all import Module
 */
export const isComponentAlreadyDeclared = (componentToFind, moduleDeclarations, moduleImports) => {
    if (moduleDeclarations &&
        moduleDeclarations
            .flat()
            .some((declaration) => declaration === componentToFind)) {
        // Found component in declarations array
        return true;
    }
    if (!moduleImports) {
        return false;
    }
    // @todo - refactor this - you can't use an async function in a `some` callback
    return moduleImports.flat().some(async (importItem) => {
        const extractedNgModuleMetadata = await extractNgModuleMetadata(importItem);
        if (!extractedNgModuleMetadata) {
            // Not an NgModule
            return false;
        }
        return isComponentAlreadyDeclared(componentToFind, extractedNgModuleMetadata.declarations || [], extractedNgModuleMetadata.imports || []);
    });
};
//# sourceMappingURL=ng-modules-analyzer.mjs.map