import { RendererWebpackBase, type Renderer as RendererType } from '@knapsack/renderer-webpack-base';
import { type CodeSrcUserConfig } from '@knapsack/types';
import { Renderable } from '@knapsack/app/renderers';
import { type KsAngularMeta } from './types';
export type { KsAngularMeta as KsNgMeta, KsAngularMeta };
type Renderer = RendererType<'angular'>;
export declare class KnapsackAngularRenderer extends RendererWebpackBase<'angular'> implements Renderable<'angular'> {
    #private;
    constructor({ customNgModulePath, wrapperComponentPath, pkgPathAliases, codeSrcs, ...extraParams }?: {
        /**
         * Path a file that has a default export of an `NgModule`
         * ```ts
         * import { NgModule } from '@angular/core';
         *
         * @NgModule({})
         * export default class CustomNgModule {}
         * ```
         */
        customNgModulePath?: string;
        /**
         * Path to a component that will wrap the template
         * ```ts
         * import { Component } from '@angular/core';
         *
         * @Component({
         *   selector: 'app-wrapper',
         *   template: '<div class="wrapper"><ng-content></ng-content></div>'
         * })
         * export default class WrapperComponent {}
         * ```
         */
        wrapperComponentPath?: string;
        pkgPathAliases?: Record<string, string>;
        codeSrcs?: CodeSrcUserConfig[];
    });
    setConfig: Renderer['setConfig'];
    init: Renderer['init'];
    watch: Renderer['watch'];
    render: Renderer['render'];
    getUsageAndImports: Renderer['getUsageAndImports'];
    getDiscovery: Renderer['getDiscovery'];
    getTemplateSuggestions: Renderer['getTemplateSuggestions'];
    inspect: Renderer['inspect'];
    getMeta: Renderer['getMeta'];
}
//# sourceMappingURL=renderer-angular.d.ts.map